@@ -98,6 +98,13 @@ test_that("body_add_toc", {
   child_ <- getncheck(node, "w:r/w:instrText")
   expect_equal( xml_text(child_), "TOC \\h \\z \\t \"Normal;1\"" )
 
+  expect_output(print(block_toc(level = 2)), "TOC - max level: 2")
+  expect_output(print(block_toc(level = 2, style = "Normal")), "TOC for style: Normal")
+  expect_output(print(block_toc(level = 2, seq_id = "tab")), "TOC for seq identifier: tab")
+
+  expect_match(to_wml(block_toc(seq_id = "tab")), "TOC \\\\h \\\\z \\\\c \"tab\"")
+  expect_match(to_wml(block_toc(style = "Normal")), "TOC \\\\h \\\\z \\\\t \"Normal;1\"")
+  expect_match(to_wml(block_toc(level = 2)), "TOC \\\\o \"1-2\" \\\\h \\\\z \\\\u")
 })
 
 test_that("body_add_img", {
@@ -192,63 +199,45 @@ test_that("add docx into docx", {
                list.files(file.path(new_dir, "word"), pattern = "\\.docx$") )
 })
 
+test_that("Add comment at cursor position", {
+  fp_bold <- fp_text_lite(bold = TRUE)
+  fp_red <- fp_text_lite(color = "red")
 
-unlink("*.docx")
+  doc <- read_docx()
+  doc <- body_add_par(doc, "This is a first Paragraph.")
+  doc <- body_comment(doc,
+                      cmt = block_list("Comment on first par."),
+                      author = "Proofreader",
+                      date = Sys.Date()
+  )
+  doc <- body_add_fpar(
+    doc,
+    fpar("This is a second Paragraph. ", "This is a third Paragraph."),
+    style = "Normal"
+  )
 
-img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
-fpt_blue_bold <- fp_text(color = "#006699", bold = TRUE)
-fpt_red_italic <- fp_text(color = "#C32900", italic = TRUE)
-bl <- block_list(
-  fpar(ftext("hello world", fpt_blue_bold)),
-  fpar(ftext("hello", fpt_blue_bold), " ",
-       ftext("world", fpt_red_italic)),
-  fpar(
-    ftext("hello world", fpt_red_italic),
-    external_img(
-      src = img.file, height = 1.06, width = 1.39)))
+  doc <- body_comment(doc,
+                      cmt = block_list(
+                        fpar(ftext("Comment on second par ...", fp_bold)),
+                        fpar(
+                          ftext("... with a second line.", fp_red)
+                        )
+                      ),
+                      author = "Proofreader 2",
+                      date = Sys.Date()
+  )
 
-anyplot <- plot_instr(code = {
-  col <- c("#440154FF", "#443A83FF", "#31688EFF",
-                      "#21908CFF", "#35B779FF", "#8FD744FF", "#FDE725FF")
-                      barplot(1:7, col = col, yaxt="n")
+  docx_file <- print(doc, target = tempfile(fileext = ".docx"))
+  docx_dir <- tempfile()
+  unpack_folder(docx_file, docx_dir)
+
+  doc <- read_xml(file.path(docx_dir, "word/comments.xml"))
+  comment1 <- xml_find_first(doc, "w:comment[@w:id='0']")
+  comment2 <- xml_find_first(doc, "w:comment[@w:id='1']")
+
+  expect_false(inherits(comment1, "xml_missing"))
+  expect_false(inherits(comment2, "xml_missing"))
+
+  expect_length(xml_children(comment1), 1)
+  expect_length(xml_children(comment2), 2)
 })
-
-test_that("visual testing", {
-  local_edition(3)
-  testthat::skip_if_not_installed("doconv")
-  testthat::skip_if_not(doconv::msoffice_available())
-  library(doconv)
-
-  x <- read_docx()
-  # add text and a table ----
-  x <- body_add_par(x, "Hello World")
-  x <- body_add_par(x, "Hello title", style = "heading 1")
-  x <- body_add_par(x, "Hello title", style = "heading 2")
-  x <- body_add_table(x, head(cars))
-  x <- body_add_par(x, "Hello base plot", style = "heading 2")
-  x <- body_add_plot(x, anyplot)
-  x <- body_add_par(x, "Hello fpars", style = "heading 2")
-  x <- body_add_blocks(x = x, blocks = bl)
-
-  expect_snapshot_doc(x = x, name = "docx-elements", engine = "testthat")
-})
-
-# test_that("body_add visual testing", {
-#   local_edition(3)
-#   testthat::skip_if_not_installed("doconv")
-#   testthat::skip_if_not(doconv::msoffice_available())
-#   library(doconv)
-#
-#   x <- read_docx()
-#   # add text and a table ----
-#   x <- body_add(x, "Hello World")
-#   x <- body_add(x, "Hello title", style = "heading 1")
-#   x <- body_add(x, "Hello title", style = "heading 2")
-#   x <- body_add(x, head(cars))
-#   x <- body_add(x, "Hello base plot", style = "heading 2")
-#   x <- body_add(x, anyplot)
-#   x <- body_add(x, "Hello fpars", style = "heading 2")
-#   x <- body_add(x = x, bl)
-#
-#   expect_snapshot_doc(x = x, name = "body_add-elements", engine = "testthat")
-# })
